@@ -14,20 +14,23 @@
   +----------------------------------------------------------------------+
 */
 
-/* $ Id: $ */
-
 #ifndef PHP_MEMCACHED_H
 #define PHP_MEMCACHED_H
 
 #include "php.h"
 #include "Zend/zend_smart_str.h"
+
+#ifdef PHP_WIN32
+#include "main/config.w32.h"
+#else
 #include "main/php_config.h"
+#endif
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
-#define PHP_MEMCACHED_VERSION "3.0.4"
+#define PHP_MEMCACHED_VERSION "3.1.3"
 
 #if defined(PHP_WIN32) && defined(MEMCACHED_EXPORTS)
 #define PHP_MEMCACHED_API __declspec(dllexport)
@@ -42,14 +45,6 @@ PHP_MEMCACHED_API zend_class_entry *php_memc_get_exception_base(int root);
 extern zend_module_entry memcached_module_entry;
 #define phpext_memcached_ptr &memcached_module_entry
 
-#ifdef ZTS
-#define MEMC_G(v) TSRMG(php_memcached_globals_id, zend_php_memcached_globals *, memc.v)
-#define MEMC_SERVER_G(v) TSRMG(php_memcached_globals_id, zend_php_memcached_globals *, server.v)
-#else
-#define MEMC_G(v) (php_memcached_globals.memc.v)
-#define MEMC_SERVER_G(v) (php_memcached_globals.server.v)
-#endif
-
 #endif /* PHP_MEMCACHED_H */
 
 /*
